<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Country;
use App\Models\User;
use Illuminate\Http\Request;

class ForeignController extends Controller
{
    public function __construct()
    {
        $this->middleware(['permission:foreign,admin']);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = User::where('type', 'foreign')->orderByDesc('id')->paginate(10);
        return view('admin.foreign.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $countries = Country::all();
        return view('admin.foreign.create', compact('countries'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'mobile' => 'required|min:10|max:10|unique:users,mobile',
            'status' => 'required|in:active,not_active',
            'trusted_office' => 'required|in:true,false',
            'country_id' => 'required|exists:countries,id',
            'password' => 'required|min:6',
            'as_requested_price' => 'required',
            'given_name_price' => 'required',
            'given_service_price' => 'required',
        ]);
        $foreign = new User();
        $foreign['name'] = $request['name'];
        $foreign['email'] = $request['email'];
        $foreign['mobile'] = $request['mobile'];
        $foreign['trusted_office'] = $request['trusted_office'];
        $foreign['country_id'] = $request['country_id'];
        $foreign['as_requested_price'] = $request['as_requested_price'];
        $foreign['given_name_price'] = $request['given_name_price'];
        $foreign['given_service_price'] = $request['given_service_price'];
        $foreign['type'] = 'foreign';
        $foreign['status'] = $request->status;
        $foreign['password'] = bcrypt($request['password']);
        $foreign->save();
        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->route('foreign.index');

    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = User::find($id);
        $countries = Country::all();
        return view('admin.foreign.edit', compact('row', 'countries'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'mobile' => 'required|min:10|max:10|unique:users,mobile,' . $id,
            'country_id' => 'required|exists:countries,id',
            'status' => 'required|in:active,not_active',
            'trusted_office' => 'required|in:true,false',
            'as_requested_price' => 'required',
            'given_name_price' => 'required',
            'given_service_price' => 'required',
            'password' => 'nullable|min:6'
        ]);
        $foreign = User::find($id);
        $foreign['name'] = $request['name'];
        $foreign['email'] = $request['email'];
        $foreign['mobile'] = $request['mobile'];
        $foreign['country_id'] = $request['country_id'];
        $foreign['trusted_office'] = $request['trusted_office'];
        $foreign['as_requested_price'] = $request['as_requested_price'];
        $foreign['given_name_price'] = $request['given_name_price'];
        $foreign['given_service_price'] = $request['given_service_price'];
        $foreign['status'] = $request['status'];
        if ($request['password']) $foreign['password'] = bcrypt($request['password']);

        $foreign->update();
        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->route('foreign.index');

    }


    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        User::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->back();
    }

    public function foreign_search(Request $request)
    {
        $this->validate($request, [
            'search' => 'required'
        ]);
        $req = $request->search;
        $search = is_numeric($request->search);
        if ($search == 1) {
            $rows = User::where('type', 'foreign')->where('mobile', 'LIKE', "%$request->search%")->paginate(10);
        } else {
            $rows = User::where('type', 'foreign')->where('name', 'LIKE', "%$request->search%")->paginate(10);
        }
        return view('admin.foreign.search', compact('rows', 'req'));
    }
}
