<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Admin;
use App\Models\Complaint;
use App\Models\Order;
use App\Models\Alert;
use App\Models\User;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class HomeController extends Controller
{
    public function login()
    {
        if (\Auth::guard('admin')->check()) {
            return redirect()->route('dashboard');
        }
        return view('admin.auth.login');

    }


    public function authenticate(Request $request)
    {

        if (\Auth::guard('admin')->attempt(['email' => $request['email'], 'password' => $request['password']])) {

            toast('مرحبا بكم في لوحة التحكم', 'success', 'left');

            return redirect()->route('dashboard');
        } else {

            \RealRashid\SweetAlert\Facades\Alert::error('خطأ في البيانات', 'البريد الألكتروني أو الرقم السري خطأ');

            return redirect()->back();
        }
    }

    public function index()
    {

//return User::whereType('saudi')->groupBy('id')->get();
        //
//        $admin = \Auth::guard('admin')->user();
//        $role = Role::where('name', $admin->email)->first();
//        $old_permissions = $admin->getAllPermissions();
//        foreach ($old_permissions as $old_permission) {
//            $role->revokePermissionTo($old_permission->name);
//        }
//
//        foreach (Permission::all() as $permission) {
//            $role->givePermissionTo($permission);
//        }


        $foreign = User::where('type', 'foreign')->get();
        $statuses = [
            'new' => 'جديد',
            'paid' => 'مدفوع',
            'foreign_accept' => 'موافقة المكتب الاجنبى',
//            'not_verified' => 'غير موثق',
            'polo' => 'فى البولو',
            'verified' => 'موثق',
            'in_shipping' => 'فى الشحن - إرسال العقود',
            'in_progress' => 'تحت الاجراء',
            'travel' => 'السفر',
            'delivered' => 'تم التوصيل',
            'cancel' => 'ملغي',
        ];
        $types = [
            'as_requested' => 'حسب المواصقات',
            'given_name' => 'اسم معين',
            'given_service' => 'خدمة معروفة'
        ];
        $alerts = Alert::orderByDesc('id')->get()->take(3);
        $complaints = Complaint::orderByDesc('id')->get()->take(3);
        $orders = Order::orderByDesc('id')->get();

        return view('admin.auth.index', compact('foreign', 'statuses', 'types', 'alerts', 'complaints', 'orders'));
    }

    public function admin_logout()
    {
        \Auth::guard('admin')->logout();
        toast('تم تسجيل الخروج بنجاح', 'success', 'top-left');

        return redirect()->route('admin_login');
    }


    public function index_search(Request $request)
    {

        $status = [
            'new' => 'جديد',
            'paid' => 'مدفوع',
            'foreign_accept' => 'موافقة المكتب الاجنبى',
//        'not_verified' => 'غير موثق',
            'polo' => 'فى البولو',
            'verified' => 'موثق',
            'in_shipping' => 'فى الشحن - إرسال العقود',
            'in_progress' => 'تحت الاجراء',
            'travel' => 'السفر',
            'delivered' => 'تم التوصيل',
            'cancel' => 'ملغي',
        ];
        $sms_rows = [];


        $orders = Order::orderByDesc('id');
        if ($request->code) {
            $orders->where('code', $request->code);
        }
        if ($request->status) {
            $orders->where('status', $request->status);
        }
        if ($request->type) {
            $orders->where('type', $request->type);
        }
        if ($request->office_id) {
            $orders->where('office_id', $request->office_id);
        }
        if ($request->from && $request->to) {
            $orders->whereBetween('created_at', [$request->from, $request->to]);
        }
        if ($request->civil_registry) {
            $orders->where('civil_registry', $request->civil_registry);
        }
        if ($request->client_name) {
            $orders->where('client_name', 'LIKE', "%{$request->client_name}%");
        }
        if ($request->worker_name) {

            $orders->whereHas('cv', function ($q) use ($request) {
                $q->where('name', 'LIKE', "%{$request->worker_name}%");
            })->OrwhereHas('order_worker', function ($q) use ($request) {
                $q->where('name', 'LIKE', "%{$request->worker_name}%");
            });

        }
        $hidden_tax = 'true';
        $rows = $orders->paginate(10);
        return view('admin.orders.all_orders', compact('rows', 'status', 'sms_rows', 'hidden_tax'));
    }


    public function alerts()
    {
        $rows = Alert::orderByDesc('id')->paginate(6);
        return view('admin.notifications', compact('rows'));
    }

    public function search_alert(Request $request)
    {
        $this->validate($request, [
            'search' => 'required'
        ]);
        $rows = Alert::where('id', $request->search)->paginate(6);
        return view('admin.notifications', compact('rows'));
    }

}
