<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Middleware\Lang;
use App\Repositories\Admin\InProgressRepository;
use App\Repositories\Client\AlertsRepository;
use App\Repositories\Worker\OrdersRepository;
use App\Repositories\Worker\SendMessagesRepository;
use Illuminate\Http\Request;

class InProgressController extends Controller
{
    /**
     * @var InProgressRepository
     */
    private $inProgressRepository;
    /**
     * @var SendMessagesRepository
     */
    private $messagesRepository;
    /**
     * @var OrdersRepository
     */
    private $ordersRepository;
    /**
     * @var AlertsRepository
     */
    private $alertsRepository;

    public function __construct(InProgressRepository $inProgressRepository, SendMessagesRepository $messagesRepository, OrdersRepository $ordersRepository, AlertsRepository $alertsRepository)
    {
        $this->inProgressRepository = $inProgressRepository;
        $this->messagesRepository = $messagesRepository;
        $this->ordersRepository = $ordersRepository;
        $this->alertsRepository = $alertsRepository;
        $this->middleware(['permission:adminInProgressOrders,admin']);
    }

    public function index()
    {
        $rows = $this->inProgressRepository->index();
        $status = [
            'new' => 'جديد',
            'paid' => 'مدفوع',
            'foreign_accept' => 'موافقة المكتب الاجنبى',
//        'not_verified' => 'غير موثق',
            'polo' => 'فى البولو',
            'verified' => 'موثق',
            'in_shipping' => 'فى الشحن - إرسال العقود',
            'in_progress' => 'تحت الاجراء',
            'travel' => 'السفر',
            'delivered' => 'تم التوصيل',
            'cancel' => 'ملغي',
        ];

        $sms_rows = [];
        return view('admin.orders.inProgressOrders', compact('rows', 'sms_rows','status'));
    }

    public function send_sms_clients()
    {

        $this->validate(request(), [
            'message' => 'required'
        ], [
            'message.required' => \Lang::get('data.pleaseEnterTheMessage'),
        ]);


        return $this->messagesRepository->send_sms_order();
    }

    public function orders_clients_ajax()
    {
        return $this->ordersRepository->orders_clients_ajax();
    }

    public function admin_notify_clients()
    {
        $this->validate(\request(), [
            'notes' => 'required',
            'type' => 'required'
        ], [
            'notes.required' => \Lang::get('data.notesRequired'),
            'type.required' => \Lang::get('data.typeRequired')
        ]);

        return $this->alertsRepository->adminStoreAlert();

    }
}
