<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Slider;
use App\Repositories\Client\SlidersRepository;
use Illuminate\Http\Request;

class SlidersController extends Controller
{
    /**
     * @var SlidersRepository
     */
    private $slidersRepository;

    public function __construct(SlidersRepository $slidersRepository)
    {
        $this->slidersRepository = $slidersRepository;
        $this->middleware(['permission:sliders,admin']);
    }


    public function index()
    {
        $rows = $this->slidersRepository->index();
        return view('admin.sliders.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.sliders.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'description_ar' => 'required',
            'description_en' => 'required',
            'image' => 'required|image'
        ]);

        return $this->slidersRepository->store();

    }

    public function edit($id)
    {
        $row = Slider::findOrFail($id);
        return view('admin.sliders.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'description_ar' => 'required',
            'description_en' => 'required',
            'image' => 'image'
        ]);
        return $this->slidersRepository->update($id);
    }

    public function destroy($id)
    {
        $this->slidersRepository->destroy($id);
    }
}
